@@ -1,5 +1,5 @@
 /*
-	Copyright (c) 2000-2010 Michael Pozhidaev<msp@altlinux.org>
+	Copyright (c) 2000-2011 Michael Pozhidaev<msp@altlinux.org>
    This file is part of the VoiceMan speech service.
 
    VoiceMan speech service is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@ void LineParser::addItem(const TextItem& item)
       return;
     }
   TextItem& last = m_items.back();
-  if (last.equalParamsTo(item))
+  if (!last.equalParamsTo(item))
     {
       m_items.push_back(item);
       return;
@@ -45,7 +45,7 @@ void LineParser::addItem(const TextItem& item)
   last.text += item.text;
 }
 
-void LineParser::processDectalkDefineVoice(StringDelimitedIterator<std::string>& it)
+void LineParser::processDectalkDefineVoice(StringDelimitedIterator<std::string>& it, size_t& pitch)
 {
   bool waitingAverPitch = 0;
   while(it.next())
@@ -64,19 +64,19 @@ void LineParser::processDectalkDefineVoice(StringDelimitedIterator<std::string>&
 	  const size_t value = parseAsUnsignedInt(s);
 	  if (value < 50 || value > 350)
 	    continue;
-	  m_pitch = (value - 50) / 3;
+	  pitch = (value - 50) / 3;
 	} //if(waitingAverPitch);
     } //while();
 }
 
-void LineParser::processDectalkCommand(const std::string& s)
+void LineParser::processDectalkCommand(const std::string& s, size_t& pitch)
 {
   StringDelimitedIterator<std::string> it(s, " \t");
   while(it.next())
     {
       if (toLower(it.str()) == ":dv")
 	{
-	  processDectalkDefineVoice(it);
+	  processDectalkDefineVoice(it, pitch);
 	  return;
 	}
     }
@@ -107,6 +107,7 @@ void  LineParser::processCommand(const std::string& command, const StringVector&
 
 void LineParser::q(const std::string& s)
 {
+  size_t pitch = m_pitch;
   std::string::size_type i = 0;
   while(i < s.length())
     {
@@ -114,13 +115,13 @@ void LineParser::q(const std::string& s)
       while(i < s.length() && s[i] != '[')
 	z += s[i++];
       if (!z.empty())
-	addItem(TextItem(z, m_pitch, m_rate, m_volume));
+	addItem(TextItem(z, pitch, m_rate, m_volume));
       if (i < s.length() && s[i] == '[')
 	{
 	  z.erase();
 	  while(i < s.length() && s[i] != ']')
 	    z += s[i++];
-	  processDectalkCommand(z);
+	  processDectalkCommand(z, pitch);
 	  i++;
 	} //dectalk commands processing;
     } //while(s[i]);
@@ -130,7 +131,9 @@ void LineParser::d()
 {
   for(TextItemList::const_iterator it = m_items.begin();it != m_items.end();it++)
     {
-      m_connection.pitch(it->pitch + m_pitchShift);
+      if (m_pitchShift >= 0 || it->pitch > (size_t)(-1 * m_pitchShift))
+	m_connection.pitch(it->pitch + m_pitchShift); else
+	m_connection.pitch(0);
       m_connection.rate(it->rate);
       m_connection.volume(it->volume);
       m_connection.text(it->text);
