@@ -1,6 +1,6 @@
 /*
-  This is the simple demonstration of connection to voicemand.
-  This program should say 'Hello!'.
+  This is the simple demonstration of voiceman connection.
+  This program must say 'Hello!'.
 To compile it run 'gcc -oexample1 example1.c -lvmclient'.
 */
 
